.. _dosenbach_atlas:

Dosenbach 2010 atlas
====================

Access
------
See :func:`nilearn.datasets.fetch_coords_dosenbach_2010`.

Notes
-----
160 regions of interest covering much of the cerebral cortex and cerebellum.
They were obtained from meta-analyses of :term:`fMRI` activation studies
and assigned into 6 networks according to a modularity analysis of
:term:`resting-state` data.

See :footcite:t:`Dosenbach2010`.

Content
-------
    :'rois': Coordinates of ROIs in :term:`MNI` space.
    :'labels': ROIs labels.
    :'networks': Networks names.

References
----------

.. footbibliography::

License
-------
